@@ -423,9 +423,8 @@ class AdapterManager:
             if resource_downloading:
                 logging.info(f"{uri} already being downloaded.")
 
-                # The resource is already being downloaded. Busy loop until
-                # it has completed. Then, just return the path to the
-                # resource.
+                # The resource is already being downloaded. Busy loop until it has
+                # completed. Then, just return the path to the resource.
                 t = 0.0
                 while id in AdapterManager.current_download_ids and t < 20:
                     sleep(0.2)
@@ -1184,9 +1183,9 @@ class AdapterManager:
     def _strip_ignored_articles(
         use_ground_truth_adapter: bool, ignored_articles: Set[str], string: str
     ) -> str:
-        first_word, *rest = string.split(maxsplit=1)
-        if first_word in ignored_articles:
-            return rest[0]
+        parts = string.split(maxsplit=1)
+        if len(parts) > 1 and parts[0] in ignored_articles:
+            return parts[1]
         return string
 
     _S = TypeVar("_S")
