@@ -444,18 +444,41 @@ class SubsonicAdapter(Adapter):
                 logging.info("Using mock data")
                 result = self._get_mock_data()
             else:
-                result = requests.get(
-                    url,
-                    params=params,
-                    verify=self.verify_cert,
-                    timeout=timeout,
-                )
+                if url.startswith("http://") or url.startswith("https://"):
+                    result = requests.get(
+                        url,
+                        params=params,
+                        verify=self.verify_cert,
+                        timeout=timeout,
+                    )
+                else:
+                    # if user creates a serverconf address w/o protocol, we'll
+                    # attempt to fix it and store it in hostname
+                    # TODO (#305) #hostname currently preprends https:// if
+                    # protocol isn't defined this might be able to be taken out
+                    try:
+                        logging.info("Hostname: %r has no protocol", self.hostname)
+                        result = requests.get(
+                            "https://" + url,
+                            params=params,
+                            verify=self.verify_cert,
+                            timeout=timeout,
+                        )
+                        self.hostname = "https://" + url.split("/")[0]
+                    except Exception:
+                        result = requests.get(
+                            "http://" + url,
+                            params=params,
+                            verify=self.verify_cert,
+                            timeout=timeout,
+                        )
+
+                        self.hostname = "http://" + url.split("/")[0]
 
             if result.status_code != 200:
                 raise ServerError(
                     result.status_code, f"{url} returned status={result.status_code}."
                 )
-
             # Any time that a server request succeeds, then we win.
             self._server_available.value = True
             self._last_ping_timestamp.value = datetime.now().timestamp()
@@ -592,8 +615,12 @@ class SubsonicAdapter(Adapter):
     def delete_playlist(self, playlist_id: str):
         self._get_json(self._make_url("deletePlaylist"), id=playlist_id)
 
-    def get_cover_art_uri(self, cover_art_id: str, scheme: str, size: int) -> str:
-        params = {"id": cover_art_id, "size": size, **self._get_params()}
+    def get_cover_art_uri(self, cover_art: str, scheme: str, size: int) -> str:
+        # Some servers return a full URL instead of an ID
+        if cover_art.startswith("http://") or cover_art.startswith("https://"):
+            return cover_art
+
+        params = {"id": cover_art, "size": size, **self._get_params()}
         return self._make_url("getCoverArt") + "?" + urlencode(params)
 
     def get_song_file_uri(self, song_id: str, schemes: Iterable[str]) -> str:
@@ -642,12 +669,14 @@ class SubsonicAdapter(Adapter):
         try:
             # If we already got the ignored articles from the get_artists, do that here.
             with open(self.ignored_articles_cache_file, "rb+") as f:
-                ignored_articles = pickle.load(f)
+                if ia := pickle.load(f):
+                    ignored_articles = ia
         except Exception:
             try:
                 # Whatever the exception, fall back on getting from the server.
                 if artists := self._get_json(self._make_url("getArtists")).artists:
-                    ignored_articles = artists.ignored_articles
+                    if ia := artists.ignored_articles:
+                        ignored_articles = ia
             except Exception:
                 # Use the default ignored articles.
                 pass
