@@ -4,6 +4,8 @@ from datetime import timedelta
 from functools import partial
 from typing import Any, Callable, Dict, Optional, Set, Tuple
 
+import bleach
+
 from gi.repository import Gdk, GdkPixbuf, GLib, GObject, Gtk, Pango
 
 from . import util
@@ -168,18 +170,20 @@ class PlayerControls(Gtk.ActionBar):
                 order_token=self.cover_art_update_order_token,
             )
 
-            self.song_title.set_markup(util.esc(app_config.state.current_song.title))
+            self.song_title.set_markup(
+                bleach.clean(app_config.state.current_song.title)
+            )
             # TODO (#71): use walrus once MYPY gets its act together
             album = app_config.state.current_song.album
             artist = app_config.state.current_song.artist
             if album:
-                self.album_name.set_markup(util.esc(album.name))
+                self.album_name.set_markup(bleach.clean(album.name))
                 self.artist_name.show()
             else:
                 self.album_name.set_markup("")
                 self.album_name.hide()
             if artist:
-                self.artist_name.set_markup(util.esc(artist.name))
+                self.artist_name.set_markup(bleach.clean(artist.name))
                 self.artist_name.show()
             else:
                 self.artist_name.set_markup("")
@@ -228,13 +232,13 @@ class PlayerControls(Gtk.ActionBar):
         new_store = []
 
         def calculate_label(song_details: Song) -> str:
-            title = util.esc(song_details.title)
-            # TODO (#71): use walrus once MYPY works with this
-            # album = util.esc(album.name if (album := song_details.album) else None)
-            # artist = util.esc(artist.name if (artist := song_details.artist) else None)  # noqa
-            album = util.esc(song_details.album.name if song_details.album else None)
-            artist = util.esc(song_details.artist.name if song_details.artist else None)
-            return f"<b>{title}</b>\n{util.dot_join(album, artist)}"
+            title = song_details.title
+            # TODO (#71): use walrus once MYPY gets its act together
+            # album = a.name if (a := song_details.album) else None
+            # artist = a.name if (a := song_details.artist) else None
+            album = song_details.album.name if song_details.album else None
+            artist = song_details.artist.name if song_details.artist else None
+            return bleach.clean(f"<b>{title}</b>\n{util.dot_join(album, artist)}")
 
         def make_idle_index_capturing_function(
             idx: int,
